==> zope_2.1.6.orig.tar.gz: Zope-2.1.6-src/inst/binary_install.py <==
##############################################################################
# 
# Zope Public License (ZPL) Version 1.0
# -------------------------------------
# 
# Copyright (c) Digital Creations.  All rights reserved.
# 
# This license has been certified as Open Source(tm).
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
# 
# 1. Redistributions in source code must retain the above copyright
#    notice, this list of conditions, and the following disclaimer.
# 
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions, and the following disclaimer in
#    the documentation and/or other materials provided with the
#    distribution.
# 
# 3. Digital Creations requests that attribution be given to Zope
#    in any manner possible. Zope includes a "Powered by Zope"
#    button that is installed by default. While it is not a license
#    violation to remove this button, it is requested that the
#    attribution remain. A significant investment has been put
#    into Zope, and this effort will continue if the Zope community
#    continues to grow. This is one way to assure that growth.
# 
# 4. All advertising materials and documentation mentioning
#    features derived from or use of this software must display
#    the following acknowledgement:
# 
#      "This product includes software developed by Digital Creations
#      for use in the Z Object Publishing Environment
#      (http://www.zope.org/)."
# 
#    In the event that the product being advertised includes an
#    intact Zope distribution (with copyright and license included)
#    then this clause is waived.
# 
# 5. Names associated with Zope or Digital Creations must not be used to
#    endorse or promote products derived from this software without
#    prior written permission from Digital Creations.
# 
# 6. Modified redistributions of any form whatsoever must retain
#    the following acknowledgment:
# 
#      "This product includes software developed by Digital Creations
#      for use in the Z Object Publishing Environment
#      (http://www.zope.org/)."
# 
#    Intact (re-)distributions of any official Zope release do not
#    require an external acknowledgement.
# 
# 7. Modifications are encouraged but must be packaged separately as
#    patches to official Zope releases.  Distributions that do not
#    clearly separate the patches from the original work must be clearly
#    labeled as unofficial distributions.  Modifications which do not
#    carry the name Zope may be packaged in any form, as long as they
#    conform to all of the clauses above.
# 
# 
# Disclaimer
# 
#   THIS SOFTWARE IS PROVIDED BY DIGITAL CREATIONS ``AS IS'' AND ANY
#   EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
#   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
#   PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL DIGITAL CREATIONS OR ITS
#   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
#   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
#   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
#   ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
#   OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
#   OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
#   SUCH DAMAGE.
# 
# 
# This software consists of contributions made by Digital Creations and
# many individuals on behalf of Digital Creations.  Specific
# attributions are listed in the accompanying credits file.
# 
##############################################################################
"""Try to do all of the installation steps.

This must be run from the top-level directory of the installation.
\(Yes, this is cheezy.  We'll fix this when we have a chance.

"""

import sys, os, getopt
from do import *

def setup(me):
    home=os.path.split(me)[0]
    if not home or home=='.': home=os.getcwd()
    home=os.path.split(home)[0]
    if not home or home=='.': home=os.getcwd()
    sys.path.insert(0, os.path.join(home))
    sys.path.insert(0, os.path.join(home,'inst'))
    return home

def main(args):
    me=args[0]
    home=setup(me)
    pcgi=os.path.join(home, 'Zope.cgi')
    usage="""install [options]

    where options are:

       -p   -- Supply the path to the PCGI resource file.
               This defaults to %s.
               Note that this path must include the file name.
    
       -g   -- Supply the name of the unix group to which
               the user that runs your web server belongs.
               If not specified, the installer will attempt
               to determine the group itself. If no group
               is specified and the installer is unable to
               determine the group, the install will fail.
    
       -u   -- Supply the name of the unix user used to
               run your web server. If not specified, this
               defaults to the userid of the current user,
               or 'nobody' is the current user is root.
    
       -h   -- Show command summary
    """ % (pcgi)
    
    try: options, args = getopt.getopt(sys.argv[1:], 'p:g:hu:')
    except: error(usage, sys.exc_info())
    if args: error('', ('Unexpected arguments', args))

    group=user=''
    for k, v in options:
        if k=='-p': pcgi=v
        elif k=='-g': group=v
        elif k=='-u': user=v
        elif k=='-h':
            print usage
            sys.exit()

    import compilezpy
    print '-'*78
    import zpasswd; zpasswd.write_access(home, user, group)
    import default_content; default_content.main(home, user, group)
    import make_resource; make_resource.main(home, pcgi, user, group)
    import make_start; make_start.sh(home, user, group)

    print '-'*78
    print
    print 'Done!'

if __name__=='__main__': main(sys.argv)

==> zope_2.5.1.orig.tar.gz: Zope-2.5.1-src/inst/binary_install.py <==
##############################################################################
#
# Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
# 
# This software is subject to the provisions of the Zope Public License,
# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE
# 
##############################################################################
"""Try to do all of the installation steps.

This must be run from the top-level directory of the installation.
\(Yes, this is cheezy.  We'll fix this when we have a chance.)

"""

import sys, os, getopt
from do import *

def setup(me):
    home=os.path.split(me)[0]
    if not home or home=='.': home=os.getcwd()
    home=os.path.split(home)[0]
    if not home or home=='.': home=os.getcwd()
    sys.path.insert(0, os.path.join(home))
    sys.path.insert(0, os.path.join(home,'inst'))
    return home

def main(args):
    me=args[0]
    home=setup(me)
    pcgi=os.path.join(home, 'Zope.cgi')
    usage="""install [options]

    where options are:

       -p   -- Supply the path to the PCGI resource file.
               This defaults to %s.
               Note that this path must include the file name.
    
       -g   -- Supply the name of the unix group to which
               the user that runs your web server belongs.
               If not specified, the installer will attempt
               to determine the group itself. If no group
               is specified and the installer is unable to
               determine the group, the install will fail.
    
       -u   -- Supply the name of the unix user used to
               run your web server. If not specified, this
               defaults to the userid of the current user,
               or 'nobody' is the current user is root.
    
       -h   -- Show command summary
    """ % (pcgi)
    
    try: options, args = getopt.getopt(sys.argv[1:], 'p:g:hu:')
    except: error(usage, sys.exc_info())
    if args: error('', ('Unexpected arguments', args))

    group=user=''
    for k, v in options:
        if k=='-p': pcgi=v
        elif k=='-g': group=v
        elif k=='-u': user=v
        elif k=='-h':
            print usage
            sys.exit()

    import compilezpy
    print '-'*78
    import zpasswd; zpasswd.write_inituser(home, user, group)
    import default_content; default_content.main(home, user, group)
    import make_resource; make_resource.main(home, pcgi, user, group)
    import make_start; make_start.sh(home, user, group)

    print '-'*78
    print
    print 'Done!'

if __name__=='__main__': main(sys.argv)
